@@ -1,5 +1,5 @@
-#ifndef _INCLUDED_HASHMAP_H_
-#define _INCLUDED_HASHMAP_H_
+#ifndef INCLUDED_HASHMAP_H_
+#define INCLUDED_HASHMAP_H_
 
 /* ======================================================================
 
