@@ -2,5 +2,5 @@
 
 char const *p_fun()
 {
-    return stack_tos(&ps_fun_st);
+    return stack_tos(&ps_fun_st)->u_charCp;
 }
